Skip to content
Merged
Changes from all commits
Commits
File filter

Filter by extension

Filter by extension

Conversations
Failed to load comments.
Loading
Jump to
Jump to file
Failed to load files.
Loading
Diff view
Diff view
5 changes: 5 additions & 0 deletions csrc/include/custom_all_reduce.cuh
Original file line number Diff line number Diff line change
Expand Up @@ -467,6 +467,7 @@ __global__ void __launch_bounds__(512, 1) cross_device_reduce_1stage(RankData* _

buf = next_buf;
}
end_sync<ngpus, true>(sg, self_sg, rank);
}

template <typename T, int ngpus, bool is_broadcast_reg_outptr = false>
Expand Down Expand Up @@ -698,6 +699,7 @@ __global__ void __launch_bounds__(512, 1) allgather_naive(
int write_idx = warp_id * size + idx;
result[write_idx] = ptrs[warp_id][idx];
}
end_sync<ngpus, true>(sg, self_sg, rank);
}

template <typename T, int ngpus>
Expand Down Expand Up @@ -725,6 +727,7 @@ __global__ void __launch_bounds__(512, 1) allgather_vec(
int write_idx = warp_id * size + idx;
*(reinterpret_cast<P*>(&result[0]) + write_idx) = ptrs[warp_id][idx];
}
end_sync<ngpus, true>(sg, self_sg, rank);
}

template <typename T, int ngpus>
Expand Down Expand Up @@ -761,6 +764,7 @@ __global__ void __launch_bounds__(512, 1) allgather_lastdim(RankData* _dp,
int write_idx = (ngpus * y + warp_id) * last_dim_size + x;
*(reinterpret_cast<P*>(&result[0]) + write_idx) = ptrs[warp_id][idx];
}
end_sync<ngpus, true>(sg, self_sg, rank);
}

/*
Expand Down Expand Up @@ -796,6 +800,7 @@ __global__ void __launch_bounds__(512, 1) reduce_scatter_first_dim(
*(reinterpret_cast<P*>(result) + store_index) =
packed_reduce<P, ngpus, A>(ptrs, load_index);
}
end_sync<ngpus, true>(sg, self_sg, rank);
}

// fp8 quant all-reduce code start
Expand Down